<?php
class BdMetabox {

	var $meta = array();

	function __construct($meta = array()){
		$this->meta = $meta + $this->meta;
		add_action('add_meta_boxes', array(&$this, 'add_meta'));
		add_action('admin_head', array(&$this, 'add_custom_scripts'));
		add_action('admin_head', array(&$this, 'meta_script_init'));
		add_action('save_post', array(&$this, 'save'));
	}



	/* Add meta box */
	function add_meta()
	{

	    	foreach ($this->meta as $k => $v){
	    		if(is_array($v['page'])){
	    			foreach($v['page'] as $p){
			    		add_meta_box(
					sanitize_title($k).'_bd_meta_box', // $id
				 	$v['title'], // $title 
				 	array(&$this, 'render'), // $callback
				 	$p, // $page
				 	'normal', // $context
				 	'high'); // $priority	
		    		}
			}else{

		    		add_meta_box(
				sanitize_title($k).'_bd_meta_box', // $id
			 	$v['title'], // $title 
			 	array(&$this, 'render'), // $callback
			 	$v['page'], // $page
			 	'normal', // $context
			 	'high'); // $priority	

			}	
	    	}
	 
	}

	/**
	* Enqueue Metabox scripts
	*/
	function meta_script_init()
	{
		if(is_admin()){
			wp_enqueue_script('jquery-ui-datepicker');
			wp_enqueue_script('jquery-ui-slider');
			wp_enqueue_script('jquery-ui-sortable');
			wp_enqueue_script('metabox', BD_FRAMEWORK_URL.'js/jquery.metabox.js');
			wp_enqueue_style('jquery-ui-custom', BD_FRAMEWORK_URL.'css/jquery-ui-custom.css');
		}
	}


	/**
	* Add jQuery slider script for review types if needed (rating)
	*/
	function add_custom_scripts()
	{
		global $post;
		$output ='';
		if(is_object($post)){
			if(preg_match("#review#", get_post_type($post->ID))){
				$output = '<script type="text/javascript">
							jQuery(function() {';
				foreach ($this->meta as $post_type) { // loop through the post types
					foreach ($post_type['metafields'] as $field) { // loop through the post types metafields array looking for certain types
						// slider
						if ($field['type'] == 'slider') {
							$value = get_post_meta($post->ID, $field['id'], true);
							if ($value == '') $value = $field['min'];
							$output .= '
							jQuery( "#'.$field['id'].'-slider" ).slider({
								value: '.$value.',
								min: '.$field['min'].',
								max: '.$field['max'].',
								step: '.$field['step'].',
								slide: function( event, ui ) {
									jQuery( "#'.$field['id'].'" ).val( ui.value );
								}
							});';
						}
					}
				}
				
				$output .= '});
				</script>';
			}	
		echo $output;
		}
	}

	// The Callback
	function render()
	{
		global $post;
		$meta_fields = array();
		
		$current_post_type = get_post_type($post->ID);

		foreach($this->meta as $k=>$v){
			if(is_array($v['page'])){
				if( in_array($current_post_type, $v['page']) ){
					$meta_fields = $v['metafields'];
				}
			}else{
				if( $current_post_type == $v['page'] ){
					$meta_fields = $v['metafields'];
				}
			}
		}

		// Use nonce for verification
		echo '<input type="hidden" name="custom_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';
		
		// Begin the field table and loop
		echo '<table class="form-table bd-metabox-table">';

		foreach($this->meta as $k=>$v){

			if(isset($v['help'])){
				echo '<div class="bd-metabox-help">'.$v['help'].'</div>';
			}

		}

		foreach ($meta_fields as $field){
			if(!isset($field['desc'])) $field['desc'] = '';
			if(!isset($field['def'])) $field['def'] = '';
			// get value of this field if it exists for this post
			$meta = get_post_meta($post->ID, $field['id'], true);
			if(!$meta)
				$meta = $field['def'];
			// begin a table row with
			echo '<tr>
			<th><label for="'.$field['id'].'">'.$field['label'].'</label></th>
			<td>';
			
				// text
				if($field['type']=='text'){
				
					echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" />
							<br /><span class="description">'.$field['desc'].'</span>';
				
				// textarea
				}elseif($field['type']=='textarea'){
					echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea>
							<br /><span class="description">'.$field['desc'].'</span>';
				
				// checkbox
				}elseif($field['type']=='checkbox'){
					echo '<input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" ',$meta ? ' checked="checked"' : '','/>
							<span class="description">'.$field['desc'].'</span>';
				
				// select
				}elseif($field['type']=='select'){
					echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
					if(array_keys($field['options']) != array_keys(array_keys($field['options']))){
						foreach ($field['options'] as $k => $option) {
							echo '<option', $meta == $k ? ' selected="selected"' : '', ' value="'.$k.'">'.$option.'</option>';
						}
					}else{
						foreach ($field['options'] as $option) {
							echo '<option', $meta == $option ? ' selected="selected"' : '', ' value="'.$option.'">'.$option.'</option>';
						}
					}
					
					echo '</select><br /><span class="description">'.$field['desc'].'</span>';
				
				// radio
				}elseif($field['type']=='radio'){
					foreach ( $field['options'] as $option ) {
						echo '<input type="radio" name="'.$field['id'].'" id="'.$option['value'].'" value="'.$option['value'].'" ',$meta == $option['value'] ? ' checked="checked"' : '',' />
								<label for="'.$option['value'].'">'.$option['label'].'</label><br />';
					}
					echo '<span class="description">'.$field['desc'].'</span>';
				
				}elseif($field['type']=='checkbox_group'){
					foreach ($field['options'] as $option) {
						echo '<input type="checkbox" value="'.$option['value'].'" name="'.$field['id'].'[]" id="'.$option['value'].'"',$meta && in_array($option['value'], $meta) ? ' checked="checked"' : '',' /> 
								<label for="'.$option['value'].'">'.$option['label'].'</label><br />';
					}
					echo '<span class="description">'.$field['desc'].'</span>';
				
				}elseif($field['type']=='tax_select'){
					echo '<select name="'.$field['id'].'" id="'.$field['id'].'">
							<option value="">Select One</option>'; // Select One
					$terms = get_terms($field['id'], 'get=all');
					$selected = wp_get_object_terms($post->ID, $field['id']);
					foreach ($terms as $term) {
						if (!empty($selected) && !strcmp($term->slug, $selected[0]->slug)) 
							echo '<option value="'.$term->slug.'" selected="selected">'.$term->name.'</option>'; 
						else
							echo '<option value="'.$term->slug.'">'.$term->name.'</option>'; 
					}
					$taxonomy = get_taxonomy($field['id']);
					echo '</select><br /><span class="description"><a href="'.get_bloginfo('home').'/wp-admin/edit-tags.php?taxonomy='.$field['id'].'">Manage '.$taxonomy->label.'</a></span>';
				
				
				}elseif($field['type']=='post_list'){
				
				$items = get_posts( array (
					'post_type'	=> $field['post_type'],
					'posts_per_page' => -1
				));
					echo '<select name="'.$field['id'].'" id="'.$field['id'].'">
							<option value="">Select One</option>'; // Select One
						foreach($items as $item) {
							echo '<option value="'.$item->ID.'"',$meta == $item->ID ? ' selected="selected"' : '','>'.$item->post_type.': '.$item->post_title.'</option>';
						} // end foreach
					echo '</select><br /><span class="description">'.$field['desc'].'</span>';
				
				
				// datepicker
				}elseif($field['type']=='datepicker'){
					echo '<input type="text" class="datepicker" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" />
							<br /><span class="description">'.$field['desc'].'</span>';
				
				}elseif($field['type']=='colorpicker'){
					?>
					<style type="text/css">
						#colorSelector<?php echo $field['id']; ?> {
								position: relative;
								margin-top:8px;
								width: 36px;
								height: 36px;
								float:left;
								background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png);
							}

						#colorSelector<?php echo $field['id']; ?> div {
							position: absolute;
							top: 3px;
							left: 3px;
							width: 30px;
							height: 30px;
							background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png) center;
							border-radius:5px; -moz-border-radius:5px; -o-border-radius:5px; -webkit-border-radius:5px;
							-ms-border-radius: 5px;-khtml-border-radius: 5px;
							cursor:pointer;
						}
					</style>
					<script type="text/javascript">
						jQuery(document).ready(function($){
						$('#colorSelector<?php echo $field['id']; ?>').ColorPicker({
								color: '<?php echo $meta;  ?>',
								onShow: function (colpkr) {
									$(colpkr).fadeIn(500);
									return false;
								},
								onHide: function (colpkr) {
									$(colpkr).fadeOut(500);
									return false;
								},
								onChange: function (hsb, hex, rgb) {
									$('#colorSelector<?php echo $field['id']; ?> div').css('backgroundColor', '#' + hex);
									$("#<?php echo $field['id']; ?>").val('#'+hex);
								}
							});
					});
					</script>
					<div id="colorSelector<?php echo $field['id']; ?>">
						<div style="background-color:<?php echo $meta; ?>">
						</div>
					</div>
					<?php
					echo '<input type="text" class="bd-colorpicker-input" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="10" /><a style="display:block;margin-top:12px" href="#" class="reset">reset</a>
							<br /><span class="description">'.$field['desc'].'</span>';


				// slider
				}elseif($field['type']=='slider'){
				$value = $meta != '' ? $meta : '0';
					echo '<div id="'.$field['id'].'-slider" class="bd-slider-meta"></div>
							<input type="text" class="bd-slider-input" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$value.'" size="5" />
							<div style="clear:both"></div>
							<span class="description">'.$field['desc'].'</span>';
				
				// file
				}elseif($field['type']=='file'){

				echo '<input type="file" name="'.$field['id'].'" id="'.$field['id'].'">
							<br><span class="description">'.$field['desc'].'</span>'; ?>
				<input type="hidden" name="<?php echo $field['id']; ?>_set" value="<?php if ( $meta  != "") { echo "set";   } else { echo ""; } ?>">
				<a href="#" class="reset">reset</a>
				<?php if ( $meta  != ""): ?>
				<div style="margin-left:15px; width:80px; min-height:10px" class="file-preview">
					<img src="<?php echo BD_UPLOAD_URL.$meta; ?>?<?php echo time(); ?>" alt="" width="80">
				</div>
				<?php endif; ?>
				<?php 
				if(BD_DEBUG)
					echo BD_UPLOAD_URL.$meta;
				?>
				<div style="clear:both"></div>
				<?php

				// image
				}elseif($field['type']=='image'){
					$image = get_template_directory_uri().'/images/image.png';	
					
					echo '<span class="custom_default_image" style="display:none">'.$image.'</span>';
					if ($meta) { $image = wp_get_attachment_image_src($meta, 'medium');	$image = $image[0]; }				
					echo	'<input name="'.$field['id'].'" type="hidden" class="custom_upload_image" value="'.$meta.'" />
								<img src="'.$image.'" class="custom_preview_image" alt="" /><br />
									<input class="custom_upload_image_button button" type="button" value="Choose Image" />
									<small>&nbsp;<a href="#" class="custom_clear_image_button">Remove Image</a></small>
									<br clear="all" /><span class="description">'.$field['desc'].'</span>';
				
				// repeatable
				}elseif($field['type']=='repeatable'){
					echo '<a class="repeatable-add button" href="#">+</a>
							<ul id="'.$field['id'].'-repeatable" class="custom_repeatable">';
					$i = 0;
					if ($meta) {
						foreach($meta as $row) {
							echo '<li><span class="sort hndle">|||</span>
										<input type="text" name="'.$field['id'].'['.$i.']" id="'.$field['id'].'" value="'.$row.'" size="30" />
										<a class="repeatable-remove button" href="#">-</a></li>';
							$i++;
						}
					} else {
						echo '<li><span class="sort hndle">|||</span>
									<input type="text" name="'.$field['id'].'['.$i.']" id="'.$field['id'].'" value="" size="30" />
									<a class="repeatable-remove button" href="#">-</a></li>';
					}
					echo '</ul>
						<span class="description">'.$field['desc'].'</span>';
				
			} //end conditions
		echo '</td></tr>';
		} // end foreach
		echo '</table>'; // end table
	}


	/**
	* Save the Data*
	* Usually "bd_{meta_value}"
	*/
	function save($post_id)
	{
	    	global $post;

	    	$meta_fields = '';
		
		// verify nonce
		if ( (isset($_POST['bd_meta_box_nonce'])) && (!wp_verify_nonce($_POST['bd_meta_box_nonce'], basename(__FILE__)))) 
			return $post_id;
		// check autosave
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions
		if(isset($_POST['post_type']) && is_object($post) ){
			//debug($_POST);
			$current_post_type = get_post_type($post->ID);
			if ('page' == $_POST['post_type']) {
				if (!current_user_can('edit_page', $post_id))
					return $post_id;
				} elseif (!current_user_can('edit_post', $post_id)) {
					return $post_id;
			}
		
			foreach($this->meta as $k=>$v){

				if(is_array($v['page']))
					$condition = isset($_POST['post_type']) && in_array($_POST['post_type'], $v['page']);
				else
					$condition =isset($_POST['post_type']) && $_POST['post_type'] == $v['page'];

				if( $condition ){
					$meta_fields = $v['metafields'];
					$img_dir = BD_UPLOAD_DIR;
					// loop through fields and save the data
					foreach ($meta_fields as $field) {
						

						if($field['type'] == 'tax_select') continue;


						if($field['type'] == 'file'){

							$meta = get_post_meta($post_id, $field['id'], true);
							
							if(!empty($_FILES[$field['id']]['name'])){
					
								$tmp = $_FILES[$field['id']]['tmp_name'];
								$ext = pathinfo($_FILES[$field['id']]['name'], PATHINFO_EXTENSION); 
								$img_name = $field['id'].'_'.$post->ID.'.'.$ext;
								$allowed_types = array('image/jpg', 'image/jpeg', 'image/gif', 'image/png');
								if(in_array($_FILES[$field['id']]['type'], $allowed_types)){
									
									//bd_delete_file(BD_UPLOAD_DIR.'/'.get_post_meta($post_id, $field['id'], true));
									
									move_uploaded_file($tmp, $img_dir.'/'.$img_name);
									
									update_post_meta($post_id, $field['id'], $img_name);

								}else{
									//bd_admin_notices(__($_FILES[$field['id']]['name'].' is not an image!!', 'bd'), 'error');
								}
										
							}elseif($_POST[$field['id'].'_set'] == ''){
								//bd_delete_file(BD_UPLOAD_DIR.'/'.get_post_meta($post_id, $field['id'], true));
								delete_post_meta($post_id, $field['id'], get_post_meta($post_id, $field['id'], true));
								
							}

						}

						if($field['type']!='file'){
						
							$old = get_post_meta($post_id, $field['id'], true);
							$new = '';
							if(isset($_POST[$field['id']]))
								$new = $_POST[$field['id']];
							
							if ($new && $new != $old) {

								update_post_meta($post_id, $field['id'], $new);
							
							} elseif ('' == $new && $old) {
								
								delete_post_meta($post_id, $field['id'], $old);
							}
						}
					
					} // enf foreach
				}
			}					
		}
	}	
}
?>