<?php
class BdPostTypes {

	var $types = array();
	var $taxonomy = array();

	function __construct($types = array(), $taxonomy = array()){
		$this->types = $types + $this->types;
		$this->taxonomy = $taxonomy + $this->taxonomy;
		$this->init();
	}

	function init(){
		add_action( 'init', array(&$this, 'register_post_type') );
		add_action( 'init', array(&$this, 'register_taxonomy') );

		add_action('admin_head', array(&$this, 'hide_text_editor'));
	}

	function hide_text_editor()
	{
		global $post;
		foreach ($this->types as $k => $v){
			$hide_text_editor = false;
			if( isset($v['hide_text_editor']) ){
				$hide_text_editor = $v['hide_text_editor'];
			}

			if( is_object($post) && get_post_type($post->ID) && $hide_text_editor == true ){
				if(  get_post_type($post->ID) == sanitize_title($k) ){

					echo '<style type="text/css">#postdivrich{display:none}</style>';
						
				}
			}
		}
	}


	function register_post_type(){
		global $options;
		
		foreach ($this->types as $k => $v){
			
			/* Format the post type array data to display it nicely in the admin panel
			---------------------------------------------------------------------------------------------*/
			$id = sanitize_title($k);
			
			$s = substr($id, -1);
			
			if($s == 's')
				$id = substr( $id , 0, -1 );

			$slug = $id;
			if(isset($v['slug']))
				$slug = sanitize_title($v['slug']);

			
			$singular = ucfirst( str_replace( array('-', '_'), ' ', $id) );
			
			if(isset($v['singular']))
				$singular = ucfirst( str_replace( array('-', '_'), ' ', $v['singular']) );
			
			
			$plural = $singular.'s';
			if(isset($v['plural']))
				$plural = ucfirst( str_replace( array('-', '_'), ' ', $v['plural']) );


			$menu_name = ucfirst($plural);
			if(isset($v['menu_name']))
				$menu_name = ucfirst($v['menu_name']);

			$labels = array(
				'name'                  => $plural, 'post type general name' ,  
				'singular_name'         => $singular, 'post type singular name' ,  
				'add_new'               => __('Add New', 'bd'), $singular  ,  
				'add_new_item'          => __('Add New', 'bd') .' '. $singular ,  
				'edit_item'             => __('Edit', 'bd') . ' '. $singular ,  
				'new_item'              =>  __('New' , 'bd'). ' '. $singular ,  
				'all_items'             => __('All' , 'bd').' '. $plural ,  
				'view_item'             => __('View', 'bd') . ' '. $singular ,  
				'search_items'          => __('Search', 'bd') . ' '. $plural ,  
				'not_found'             =>  __('No', 'bd').' '. strtolower($plural) . ' '. __('found', 'bd'),  
				'not_found_in_trash'    => __('No', 'bd') .' '. strtolower($plural)  . ' '. __('found in Trash', 'bd'),  
				'parent_item_colon'     => '',  
				'menu_name'             => $menu_name,

			);


			$supports = array('title','editor','thumbnail');
			$exclude_from_search = true;
			
			if( isset($v['supports']) && is_array($v['supports']) ){
				$supports = $v['supports'];
			}

			if(isset($v['exclude_from_search'])){
				$exclude_from_search = $v['exclude_from_search'];
			}

			$args = array(
				'labels' => $labels,
				'public' => true,
				'publicly_queryable' => true,
				'show_ui' => true,
				'show_in_menu' => true,
				'query_var' => false,
				'rewrite' => array('slug' => $slug),
				'capability_type' => 'post',
				'has_archive' => false,
				'hierarchical' => false,
				'menu_position' => 5,
				'taxonomies' => array(),
				'supports' => $supports,
				'exclude_from_search' => $exclude_from_search,

			);
			register_post_type($id, $args);


		}
	}


	function register_taxonomy(){

		foreach ($this->taxonomy as $k => $v){
			
			$post_types = array('page');
			if( isset($v['post-types']) && is_array($v['post-types']) )
				$post_types = $v['post-types'];

			$type = 'category';
			if(isset($v['type']))
				$type = $v['type'];

			/* Format the taxonomy array data to display it nicely in the admin panel
			---------------------------------------------------------------------------------------------*/

			$id = sanitize_title($k);
			
			$s = substr($id, -1);
			
			if($s == 's')
				$id = substr( $id , 0, -1 );

			$slug = $id;
			if(isset($v['slug']))
				$slug = sanitize_title($v['slug']);

			
			$singular = ucfirst( str_replace( array('-', '_'), ' ', $id) );
			
			if(isset($v['singular']))
				$singular = ucfirst( str_replace( array('-', '_'), ' ', $v['singular']) );
			
			
			$plural = $singular.'s';
			if(isset($v['plural']))
				$plural = ucfirst( str_replace( array('-', '_'), ' ', $v['plural']) );


			$menu_name = ucfirst($plural);
			if(isset($v['menu_name']))
				$menu_name = ucfirst($v['menu_name']);
			
			$labels = array(
				'name' => $singular, 'taxonomy general name',
				'singular_name' => $singular, 'taxonomy singular name' ,
				'search_items'          => __('Search', 'bd') . ' ' . $plural , 
				'popular_items' => __('Popular', 'bd') .' '.$plural ,
				'all_items' => __('All', 'bd') .' '.$plural ,
				'parent_item' => null,
				'parent_item_colon' => null,
				'edit_item' => __('Edit', 'bd') .' '.$singular ,
				'update_item' => __('Update', 'bd') .' '.$singular ,
				'add_new_item' => __('Add New', 'bd') .' '.$singular ,
				'new_item_name' => __('New', 'bd') .' '.$singular .' '.__('Name', 'bd') ,
				'separate_items_with_commas' => __('Separate', 'bd') .' '.strtolower($plural).' '.__('with commas', 'bd') ,
				'add_or_remove_items' => __('Add or remove', 'bd') .' '.$singular ,
				'choose_from_most_used' => __('Choose from the most used', 'bd') .' '.strtolower($plural) ,
				'menu_name' => $menu_name ,
			);

			if($type == 'category'){

				register_taxonomy($id, $post_types, array(
					'hierarchical' => true,
					'labels' => $labels,
					'show_ui' => true,
					'query_var' => true,
					'rewrite' => array( 'slug' => $slug, 'with_front' => false),
				));

			}elseif($type == 'tags'){
				register_taxonomy($id, $post_types, array(
					'hierarchical' => false,
					'labels' => $labels,
					'show_ui' => true,
					'update_count_callback' => '_update_post_term_count',
					'query_var' => true,
					'rewrite' => array( 'slug' => $slug, 'with_front' => false),
				));

				
			}	

		}


	}


}
?>