<?php 
/*--------------------------------------------------------------------------------------------------------------

	Sidebar Manager v1.5
	Inbuit plugin for BrutalDesign framework

----------------------------------------------------------------------------------------------------------------*/

class BdSidebars{
	
	function __construct()
	{

		define('BD_WIDGET_AREA', true);
		define('BD_SIDEBARS_PLUGIN_DIR', dirname(__FILE__));
		define('BD_SIDEBARS_PLUGIN_URL', BD_FRAMEWORK_URL.basename(dirname(__FILE__)).'/');
		
		
		add_action('after_setup_theme', array( &$this, 'create_sidebar_table' ) );
		add_action('after_setup_theme', array( &$this, 'register_custom_sidebars' ) );
		add_action('admin_menu', array( &$this, 'add_menu' ) );
		add_action('add_meta_boxes', array( &$this, 'add_sidebar_meta_box' ) );
		add_action('save_post', array( &$this, 'save_sidebar_metabox' ) );
		
	}
	


	/**
	* Create sidebar Table
	*/
	function create_sidebar_table()
	{
		global $wpdb;
		$sidebar_tbl ="CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}bd_sidebars` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `wp_id` varchar(255) NULL,
		  `name` varchar(255) NULL,
		  `desc` text NULL,
		  `type` text NULL,
		  `position` int(11) NOT NULL DEFAULT 0,
		  PRIMARY KEY (`id`)
		);";
		$wpdb->query($sidebar_tbl);
	}


	function get_bd_sidebars()
	{
		global $wpdb;
		$bd_sidebars_table = $wpdb->prefix.'bd_sidebars';
		$sidebars = $wpdb->get_results("SELECT * FROM $bd_sidebars_table ORDER BY position");
		return $sidebars;

	}

	

	/*
	*  Register created sidebars
	*/
	function register_custom_sidebars()
	{
		global $options;

		$sidebars = $this->get_bd_sidebars();
		
		if( $sidebars ){
			foreach($sidebars as $sidebar){

				if( $sidebar->type =='sidebar'){

					$args = array(
						'name'      => $sidebar->name,
						'id'            => $sidebar->wp_id,
						'description' => $sidebar->desc,
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget'  => '</div><hr>',
						'before_title'  => '<h3 class="widget-title">',
						'after_title'   => '</h3>',
					);

				}elseif($sidebar->type=='widgetarea'){
					
					$args = array(
						'name'      => $sidebar->name. ' ('.$sidebar->type.')',
						'id'            => $sidebar->wp_id,
						'description' => $sidebar->desc,
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget'  => '</div>',
						'before_title'  => '<h3 class="widget-title">',
						'after_title'   => '</h3>'
					);
				}

				register_sidebar($args);
			}
		}
	}
	


	/*
	*  Add contextual menu
	*/
	function add_menu()
	{
		add_menu_page(__('Sidebars', 'bd'), __('Sidebars', 'bd'), 'administrator', basename(__FILE__), array(&$this, 'sidebars_admin') , BD_SIDEBARS_PLUGIN_URL.'img/bd_sidebars.png');
	}



	/*
	*  Add Sidebar Metabox to the admin interface
	*/
	function add_sidebar_meta_box()
	{
		global $post;
		$current_post_type  ='';
		if($post)
			$current_post_type = get_post_type($post->ID);

		if($current_post_type == 'page') {
		add_meta_box(
			'sidebar_meta_box', // $id
			'Sidebar', // $title 
			array(&$this,'show_sidebars_list'), // $callback
			'page', // $page
			'side', // $context
			'default'); // $priority
		}
	}
	

	/*
	*  Add select input in the post editor to choose which sidebar to use on the page
	*/
	function show_sidebars_list()
	{
		global $options, $post, $BD_theme;
		$sidebars = $this->get_bd_sidebars();

		$meta = get_post_meta($post->ID, 'bd_sidebar', true);

		//echo $meta;

		if(function_exists('bd_post_types_sidebars'))
			
			$bd_sidebars = bd_post_types_sidebars();

		else
			$bd_sidebars = $BD_theme['post-types'];
		
		?>
		<select name="bd_sidebar" id="bd_sidebar">
			<option value="main" <?php if($meta=='main'){ echo 'selected="selected"';} ?>>Blog Sidebar</option>
			<?php foreach($bd_sidebars as $k => $v): 
				$id = bd_to_slug($k);
			
				$s = substr($id, -1);
				
				if($s == 's')
					$id = substr( $id , 0, -1 );

				$slug = $id;
				if(isset($v['slug']))
					$slug = bd_to_slug($v['slug']);

				
				$singular = ucfirst( str_replace( array('-', '_'), ' ', $id) );
				
				if(isset($v['singular']))
					$singular = ucfirst( str_replace( array('-', '_'), ' ', $v['singular']) );
				
				
				$plural = $singular.'s';
				if(isset($v['plural']))
					$plural = ucfirst( str_replace( array('-', '_'), ' ', $v['plural']) );

				$menu_name = ucfirst($plural);
				if(isset($v['menu_name']))
					$menu_name = ucfirst($v['menu_name']);
				?>
				<option value="<?php echo $id; ?>" <?php if($meta==$id) echo 'selected="selected"'; ?>><?php echo ucfirst($menu_name).' Sidebar'; ?></option>
			<?php endforeach; ?>

			<?php foreach($sidebars as $s):
				if($s->type == 'sidebar'):
			?>
				<option value="<?php echo $s->wp_id?>" <?php if($meta==$s->wp_id) echo 'selected="selected"'; ?>><?php echo $s->name; ?></option>
			<?php endif; endforeach; ?>
		</select>
		<p><em><?php _e('Note that not all templates have a sidebar.', 'bd'); ?></em></p>
		<?php
	}


	/*
	*  Save Sidebar meta
	*/
	function save_sidebar_metabox($post_id)
	{
		// verify nonce
		if ( (isset($_POST['sidebar_meta_box_nonce'])) && (!wp_verify_nonce($_POST['sidebar_meta_box_nonce'], basename(__FILE__)))) 
			return $post_id;
		// check autosave
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions
		if(isset($_POST['post_type'])){
			if ('page' == $_POST['post_type']) {
				if (!current_user_can('edit_page', $post_id))
					return $post_id;
				} elseif (!current_user_can('edit_post', $post_id)) {
					return $post_id;
			}
		}

		if((isset($_POST['post_type'])) && ($_POST['post_type']=='page')){
			if(isset($_POST['bd_sidebar'])){
				
				$old = get_post_meta($post_id, 'bd_sidebar', true);
				$new = $_POST['bd_sidebar'];
				
				if ($new && $new != $old ) {
					
					update_post_meta($post_id, 'bd_sidebar', $new);
				
				} elseif ('' == $new && $old) {
					
					delete_post_meta($post_id, 'bd_sidebar', $old);
				}
			}
		}
	}
	

	function sidebars_admin()
	{
		require "bd-sidebars-panel.php";
	}

}
$bd_custom_sidebars = new BdSidebars;
?>