<?php
/*-----------------------------------------------------------------------------------*/
/*  Default filters
/*-----------------------------------------------------------------------------------*/

/**
* Configure WP Title
*/
if ( !function_exists( 'bd_wp_title' ) ) {
    function bd_wp_title($title) {
           if( is_front_page() ){
                return get_bloginfo('name') .' | '. get_bloginfo('description'); 
            } else {
                return trim($title) .' | '. get_bloginfo('name');
            }
    }
}
add_filter('wp_title', 'bd_wp_title');



/**
* Menu fallback function 
* (display the list of pages as menu if no menu is created)
*/
function bd_page_menu_args( $args ) {
    $args['sort_column'] = 'post_date';
    return $args;
}
add_filter( 'wp_page_menu_args', 'bd_page_menu_args' );


/**
* Hook to set the email input of the comment form as email type 
* (usefull for tablet and mobile)
*/
function bd_change_comment_form_defaults( $default )
{
    $commenter = wp_get_current_commenter();
    $req = get_option( 'require_name_email' );
    $aria_req = ( $req ? " aria-required='true'" : '' );
    $default[ 'fields' ][ 'email' ] = '<p class="comment-form-email">
    <label for="email">' . __( 'Email', 'bd' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) . '<input id="email" name="email" type="email" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';
    return $default;
}
add_filter( 'comment_form_defaults', 'bd_change_comment_form_defaults');


/**
* Exclude "page" post type from search results
*/
function bd_exclude_pages_from_search()
{
    global $wp_post_types;
    $wp_post_types['page']->exclude_from_search = true;
}
add_action('init', 'bd_exclude_pages_from_search');


/**
* Set Default Avatar
*/
function bd_gravatar ($avatar_defaults) {
    global $options;
    if(bd_get_option('default_avatar')){

        $myavatar = BD_UPLOAD_URL.bd_get_option('default_avatar');
        
    }else{

        $myavatar = BD_THEME_URL . 'images/default_avatar.jpg';
     
    }
    $avatar_defaults[$myavatar] = "My avatar";
    return $avatar_defaults;
}
add_filter( 'avatar_defaults', 'bd_gravatar' );


/**
* Add a menu class to the fallback menu
* In case if the user didn't set any menu in the WP menu  admin panel
*/
function bd_add_menuclass ($page_markup) {
    preg_match('/^<div class=\"([a-z0-9-_]+)\">/i', $page_markup, $matches);
    $divclass = $matches[1];
    $toreplace = array('<div class="'.$divclass.'">', '</div>');
    $new_markup = str_replace($toreplace, '', $page_markup);
    $new_markup = preg_replace('/^<ul>/i', '<ul class="default-menu">', $new_markup);
    return $new_markup; 
}
add_filter('wp_page_menu', 'bd_add_menuclass');


/**
* Add featured image to the WP RSS feed
*/
function bd_add_featured_image_to_RSS($content) {
    global $post;
    if( has_post_thumbnail($post->ID) ) {
        $content = '<div>' . get_the_post_thumbnail($post->ID, 'archive-thumb') . '</div>' . $content;
    }

    return $content;
}
add_filter('the_excerpt_rss', 'bd_add_featured_image_to_RSS');
add_filter('the_content_feed', 'bd_add_featured_image_to_RSS');

/*-----------------------------------------------------------------------------------*/
/*  Remove Generator for Security
/*-----------------------------------------------------------------------------------*/

remove_action( 'wp_head', 'wp_generator' );
