<?php
/*--------------------------------------------------------------------------------------------------------------

	Plugin Name: Bd flexslider Plugin
	Plugin URI: http://themes.brutaldesign.com
	Description: Manage your image and display a responsive slider in your theme (in-buit plugin)
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

----------------------------------------------------------------------------------------------------------------*/

class BdFlexSlider {


	function __construct(){
		define('BD_FLEXSLIDER_URL', BD_FEATURES_URL.basename(dirname(__FILE__)).'/');
		define('BD_FLEXSLIDER_DIR', dirname(__FILE__) );
		define('BD_FLEXSLIDER_FILES_DIR', BD_THEME_UPLOAD_DIR.'/bd-flexslider');
		define('BD_FLEXSLIDER_FILES_URL',  BD_THEME_UPLOAD_URL.'bd-flexslider/');
	
		if(function_exists('bd_create_folder')){
			
			bd_create_folder(BD_FLEXSLIDER_FILES_DIR);
			bd_create_folder(BD_FLEXSLIDER_FILES_DIR.'/slides');

		}else{

			bd_admin_notices( __('Unable to find bd_create_folder function.', 'bd'), 'error' );
		}

		add_action('init', array(&$this, 'options_init') );
		add_action('after_setup_theme',  array(&$this, 'flexslider_show') );

		add_action('admin_init', array(&$this, 'create_table') );
		add_action('admin_init', array(&$this, 'admin_init'));

		add_action('admin_menu', array(&$this, 'menu_init'));

		add_action('admin_print_styles', array(&$this, 'admin_styles'));
		add_action('admin_enqueue_scripts', array(&$this, 'admin_script'));

	}

	// --------------------------------------------------------------------------

	/**
	* Create flexslider Table
	*/
	function create_table()
	{
		global $wpdb;
		$slider_tbl ="CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}bd_flexslider` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `img` varchar(255) NOT NULL,
		  `link` text NULL,
		  `caption` text NULL,
		  `position` int(11) NOT NULL DEFAULT 0,
		  `coordinates` varchar(255) NULL,
		  `language_code` varchar(7) NOT NULL DEFAULT 'en',
		  PRIMARY KEY (`id`)
		);";
		$wpdb->query($slider_tbl);

		/* Check language column (WPML plugin compatibility) for theme version < 1.3 */
		$req = "SELECT * FROM `{$wpdb->prefix}bd_flexslider` LIMIT 1";
		$check_col = $wpdb->get_row($req);
		if(!isset($check_col->language_code)){
			$add_col = "ALTER TABLE `{$wpdb->prefix}bd_flexslider` ADD COLUMN `language_code` VARCHAR(7) NOT NULL DEFAULT 'en'";
			$wpdb->query($add_col);
		}

	}

	// --------------------------------------------------------------------------


	function admin_styles()
	{
		if(isset( $_GET['page'] ) ){
			
			$page = $_GET['page'];
			
			if( $page == 'bd-flexslider-panel' || $page == 'bd-flexslider.php' ){

				wp_enqueue_style('bd-flexslider-admin', BD_FLEXSLIDER_URL.'css/bd-admin.css', array(), '0.1', 'all');
				wp_enqueue_style('imagareaselect', BD_FLEXSLIDER_URL.'css/imgareaselect/imgareaselect-animated.css', array(), '0.9.8', 'all');
			}
		}
	}

	// --------------------------------------------------------------------------

	function admin_script()
	{
		if( isset( $_GET['page'] ) ){
			$page = $_GET['page'];
			
			$page = $_GET['page'];
			
			if( $page == 'bd-flexslider-panel' || $page == 'bd-flexslider.php' ){

				wp_enqueue_script( 'imagareaselect', BD_FLEXSLIDER_URL.'js/jquery.imgareaselect.pack.js', 'jquery', '0.9.8', true );
				
				if( !wp_script_is( 'jquery-ui-sortable' ) )
					wp_enqueue_script( 'jquery-ui-sortable' );
			}
		}
	}

	// --------------------------------------------------------------------------

	function menu_init()
	{
		// Add Contextual menu
		add_menu_page('Header Slider', 'Header Slider', 'administrator', basename(__FILE__), array(&$this, 'flexslider_panel'), BD_FLEXSLIDER_URL.'img/admin/menu.png');
		add_submenu_page(basename(__FILE__),'','','administrator',basename(__FILE__),array(&$this, 'flexslider_panel'));
		add_submenu_page(basename(__FILE__), 'Images', 'Images', 'administrator', 'bd-flexslider-panel',  array(&$this, 'flexslider_panel') );
		add_submenu_page(basename(__FILE__),  'Header Slider Options', 'Options', 'administrator', 'bd-flexslider-settings', array(&$this, 'flexslider_settings'));

	}


	// --------------------------------------------------------------------------

	function admin_init()
	{
		register_setting( 'bd-flexslider-settings', 'bd_flexslider_settings', array(&$this, 'settings_validate') );
		add_settings_section( 'bd-flexslider-settings', '', array(&$this, 'section_intro'), 'bd-flexslider-settings' );
		add_settings_field( 'height', __( 'Height', 'bd' ), array(&$this, 'setting_height'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'effect', __( 'Transition effect', 'bd' ), array(&$this, 'setting_effect'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'pausetime', __( 'Time between animation in milisecond', 'bd' ), array(&$this, 'setting_pausetime'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'duration', __( 'Slide transition speed', 'bd' ), array(&$this, 'setting_duration'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'autoplay', __( 'Autoplay', 'bd' ), array(&$this, 'setting_autoplay'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'direction', __( 'Navigation arrows', 'bd' ), array(&$this, 'setting_direction'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'control', __( 'Navigation bullets', 'bd' ), array(&$this, 'setting_control'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
		add_settings_field( 'pausehover', __( 'Stop animation while the mouse is on the slide', 'bd' ), array(&$this, 'setting_pausehover'), 'bd-flexslider-settings', 'bd-flexslider-settings' );
	}

	// --------------------------------------------------------------------------

	function options_init()
	{
		global $options;

		if ( false === get_option('bd_flexslider_settings') ) {

			$default = array(
				'height' => 200,
				'effect' => 'fade',
				'pausetime' => 3500,
				'duration' => 800,
				'autoplay' => 'true',
				'direction' => 'true',
				'control' => 'true',
				'pausehover' => 'true',

			);

			add_option( 'bd_flexslider_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	function section_intro()
	{
		// global $options;
		// debug(get_option('bd_flexslider_settings'));
	}

	// --------------------------------------------------------------------------

	function settings_validate($input)
	{
		$input['height'] = intval($input['height']);
		$input['duration'] = intval($input['duration']);
		$input['pausetime'] = intval($input['pausetime']);
		return $input;
	}

	// --------------------------------------------------------------------------

	function setting_width()
	{
		?>
		<select name="bd_flexslider_settings[width]">
			<option value="1920" <?php if($this->get_flexslider_option('width') == 1920) echo 'selected="selected"' ?>><?php _e('Full Width', 'bd'); ?></option>
			<option value="1140" <?php if($this->get_flexslider_option('width') == 1140) echo 'selected="selected"' ?>><?php _e('Wrapped', 'bd'); ?></option>
		</select>
		<?php
	}

	// --------------------------------------------------------------------------

	function setting_height()
	{
		
		echo '<input type="text" name="bd_flexslider_settings[height]" class="regular-text" value="'. $this->get_flexslider_option('height') .'" />';
	}

	// --------------------------------------------------------------------------

	function setting_effect()
	{
		?>
		<select name="bd_flexslider_settings[effect]">
			<option value="slide" <?php if($this->get_flexslider_option('effect') == 'slide') echo 'selected="selected"' ?>>Slide</option>
			<option value="fade" <?php if($this->get_flexslider_option('effect') == 'fade') echo 'selected="selected"' ?>>Fade</option>
		</select>
		<?php
	}

	// --------------------------------------------------------------------------


	function setting_pausetime()
	{
		
		echo '<input type="text" name="bd_flexslider_settings[pausetime]" class="regular-text" value="'. $this->get_flexslider_option('pausetime') .'" />';
	}

	// --------------------------------------------------------------------------

	function setting_duration()
	{
		
		echo '<input type="text" name="bd_flexslider_settings[duration]" class="regular-text" value="'. $this->get_flexslider_option('duration') .'" />';
	}

	// --------------------------------------------------------------------------


	function setting_autoplay()
	{
		echo '<input type="hidden" name="bd_flexslider_settings[autoplay]" value="false" />
		<label><input type="checkbox" name="bd_flexslider_settings[autoplay]" value="true"'. (($this->get_flexslider_option('autoplay') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------


	function setting_direction()
	{
		echo '<input type="hidden" name="bd_flexslider_settings[direction]" value="false" />
		<label><input type="checkbox" name="bd_flexslider_settings[direction]" value="true"'. (($this->get_flexslider_option('direction') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------

	function setting_control()
	{
		echo '<input type="hidden" name="bd_flexslider_settings[control]" value="false" />
		<label><input type="checkbox" name="bd_flexslider_settings[control]" value="true"'. (($this->get_flexslider_option('control') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------

	function setting_pausehover()
	{
		echo '<input type="hidden" name="bd_flexslider_settings[pausehover]" value="false" />
		<label><input type="checkbox" name="bd_flexslider_settings[pausehover]" value="true"'. (($this->get_flexslider_option('pausehover') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------

	function flexslider_settings()
	{
		?>
		<div class="wrap">
			<div id="icon-themes" class="icon32"></div>
			<h2><?php _e('Flexslider Settings', 'bd'); ?></h2>
			<form action="options.php" method="post">
				<?php settings_fields( 'bd-flexslider-settings' ); ?>
				<?php do_settings_sections( 'bd-flexslider-settings' ); ?>
				<p class="submit"><input name="save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'bd' ); ?>" /></p>
			</form>
			<p style="margin-top:20px"><?php _e('Visit the official Flexslider Website', 'bd'); ?>:<br><a target="_blank" href="http://www.woothemes.com/flexslider/">http://www.woothemes.com/flexslider/</a></p>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------

	function get_flexslider_option($value = null)
	{
		global $options;

		$bd_flexslider_settings = get_option('bd_flexslider_settings');
		
		if( isset($bd_flexslider_settings[$value]) )
			return $bd_flexslider_settings[$value];
		else
			return null;
	}

	// --------------------------------------------------------------------------

	function flexslider_panel()
	{
		include_once BD_FLEXSLIDER_DIR . '/bd-flexslider-panel.php';
	}

	// --------------------------------------------------------------------------

	function flexslider_show()
	{
		include_once BD_FLEXSLIDER_DIR . '/bd-flexslider-show.php';
	}


} // end class
$bd_flexslider = new BdFlexSlider;
?>