<?php
/*--------------------------------------------------------------------------------------------------------------

	Plugin Name: Bd RefineSlide Plugin
	Plugin URI: http://themes.brutaldesign.com
	Description: Manage your image and display a responsive slider in your theme (in-buit plugin)
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

----------------------------------------------------------------------------------------------------------------*/

class BdRefineSlide {


	function __construct(){
		define('BD_REFINESLIDE_URL', BD_FEATURES_URL.basename(dirname(__FILE__)).'/');
		define('BD_REFINESLIDE_DIR', dirname(__FILE__) );
		define('BD_REFINESLIDE_FILES_DIR',  BD_THEME_UPLOAD_DIR . '/bd-refineslide');
		define('BD_REFINESLIDE_FILES_URL',  BD_THEME_UPLOAD_URL . 'bd-refineslide/');
	
		if(function_exists('bd_create_folder')){
			
			bd_create_folder(BD_REFINESLIDE_FILES_DIR);
			bd_create_folder(BD_REFINESLIDE_FILES_DIR.'/slides');

		}else{

			bd_admin_notices( __('Unable to find bd_create_folder function.', 'bd'), 'error' );
		}

		add_action('init', array(&$this, 'options_init') );
		add_action('after_setup_theme',  array(&$this, 'refineslide_show') );

		add_action('admin_init', array(&$this, 'create_table') );
		add_action('admin_init', array(&$this, 'admin_init'));

		add_action('admin_menu', array(&$this, 'menu_init'));

		add_action('admin_print_styles', array(&$this, 'admin_styles'));
		add_action('admin_enqueue_scripts', array(&$this, 'admin_script'));

	}

	// --------------------------------------------------------------------------

	/**
	* Create refineslide Table
	*/
	function create_table()
	{
		global $wpdb;
		$slider_tbl ="CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}bd_refineslide` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `img` varchar(255) NOT NULL,
		  `link` text NULL,
		  `caption` text NULL,
		  `caption_position` varchar(255) NOT NULL DEFAULT 'bottom-right',
		  `position` int(11) NOT NULL DEFAULT 0,
		  `coordinates` varchar(255) NULL,
		  `language_code` varchar(7) NOT NULL DEFAULT 'en',
		  PRIMARY KEY (`id`)
		);";
		$wpdb->query($slider_tbl);

		/* Check language column (WPML plugin compatibility) for theme version < 1.3 */
		$req = "SELECT * FROM `{$wpdb->prefix}bd_refineslide` LIMIT 1";
		$check_col = $wpdb->get_row($req);
		if(!isset($check_col->language_code)){
			$add_col = "ALTER TABLE `{$wpdb->prefix}bd_refineslide` ADD COLUMN `language_code` VARCHAR(7) NOT NULL DEFAULT 'en'";
			$wpdb->query($add_col);
		}

	}

	// --------------------------------------------------------------------------


	function admin_styles()
	{
		if(isset( $_GET['page'] ) ){
			
			$page = $_GET['page'];
			
			if( $page == 'bd-refineslide-panel' || $page == 'bd-refineslide.php' ){

				wp_enqueue_style('bd-refineslide-admin', BD_REFINESLIDE_URL.'css/bd-admin.css', array(), '0.1', 'all');
				wp_enqueue_style('imagareaselect', BD_REFINESLIDE_URL.'css/imgareaselect/imgareaselect-animated.css', array(), '0.9.8', 'all');
			}
		}
	}

	// --------------------------------------------------------------------------

	function admin_script()
	{
		if( isset( $_GET['page'] ) ){
			$page = $_GET['page'];
			
			$page = $_GET['page'];
			
			if( $page == 'bd-refineslide-panel' || $page == 'bd-refineslide.php' ){

				wp_enqueue_script( 'imagareaselect', BD_REFINESLIDE_URL.'js/jquery.imgareaselect.pack.js', 'jquery', '0.9.8', true );
				
				if( !wp_script_is( 'jquery-ui-sortable' ) )
					wp_enqueue_script( 'jquery-ui-sortable' );
			}
		}
	}

	// --------------------------------------------------------------------------

	function menu_init()
	{
		// Add Contextual menu
		add_menu_page('Home Slider', 'Home Slider', 'administrator', basename(__FILE__), array(&$this, 'refineslide_panel'), BD_REFINESLIDE_URL.'img/admin/menu.png');
		add_submenu_page(basename(__FILE__),'','','administrator',basename(__FILE__),array(&$this, 'refineslide_panel'));
		add_submenu_page(basename(__FILE__), 'Images', 'Images', 'administrator', 'bd-refineslide-panel',  array(&$this, 'refineslide_panel') );
		add_submenu_page(basename(__FILE__),  'Home Slider Options', 'Options', 'administrator', 'bd-refineslide-settings', array(&$this, 'refineslide_settings'));

	}


	// --------------------------------------------------------------------------

	function admin_init()
	{
		register_setting( 'bd-refineslide-settings', 'bd_refineslide_settings', array(&$this, 'settings_validate') );
		add_settings_section( 'bd-refineslide-settings', '', array(&$this, 'section_intro'), 'bd-refineslide-settings' );
		add_settings_field( 'height', __( 'Height', 'bd' ), array(&$this, 'setting_height'), 'bd-refineslide-settings', 'bd-refineslide-settings' );
		add_settings_field( 'effect', __( 'Transition Effect', 'bd' ), array(&$this, 'setting_effect'), 'bd-refineslide-settings', 'bd-refineslide-settings' );
		add_settings_field( 'delay', __( 'Time between animation in milliseconds', 'bd' ), array(&$this, 'setting_delay'), 'bd-refineslide-settings', 'bd-refineslide-settings' );
		add_settings_field( 'transition_duration', __( 'Transition Duration', 'bd' ), array(&$this, 'setting_transition_duration'), 'bd-refineslide-settings', 'bd-refineslide-settings' );
		add_settings_field( 'navigation', __( 'Navigation', 'bd' ), array(&$this, 'setting_navigation'), 'bd-refineslide-settings', 'bd-refineslide-settings' );
		add_settings_field( 'autoplay', __( 'Autoplay', 'bd' ), array(&$this, 'setting_autoplay'), 'bd-refineslide-settings', 'bd-refineslide-settings' );
	}

	// --------------------------------------------------------------------------

	function options_init()
	{
		global $options;

		if ( false === get_option('bd_refineslide_settings') ) {

			$default = array(
				'height' => 450,
				'autoplay' => 'true',
				'delay' => 4000,
				'effect' => 'random',
				'transition_duration' => 1000,
				'navigation' => 'arrows'

			);

			add_option( 'bd_refineslide_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	function section_intro()
	{
		// global $options;
		// debug(get_option('bd_refineslide_settings'));
	}

	// --------------------------------------------------------------------------

	function settings_validate($input)
	{
		$input['height'] = intval( $input['height'] );
		$input['delay'] = intval( $input['delay'] );
		$input['transition_duration'] = intval( $input['transition_duration'] );
		$input['effect'] = esc_attr( $input['effect'] );
		$input['navigation'] = esc_attr( $input['navigation'] );

		return $input;
	}

	// --------------------------------------------------------------------------

	function setting_height()
	{
		
		echo '<input type="text" name="bd_refineslide_settings[height]" class="regular-text" value="'. $this->get_refineslide_option('height') .'">';
	}

	// --------------------------------------------------------------------------

	function setting_delay()
	{
		
		echo '<input type="text" name="bd_refineslide_settings[delay]" class="regular-text" value="'. $this->get_refineslide_option('delay') .'">';
	}

	// --------------------------------------------------------------------------

	function setting_transition_duration()
	{
		
		echo '<input type="text" name="bd_refineslide_settings[transition_duration]" class="regular-text" value="'. $this->get_refineslide_option('transition_duration') .'">';
	}

	// --------------------------------------------------------------------------


	function setting_autoplay()
	{
		echo '<input type="hidden" name="bd_refineslide_settings[autoplay]" value="false" />
		<label><input type="checkbox" name="bd_refineslide_settings[autoplay]" value="true"'. (($this->get_refineslide_option('autoplay') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------

	function setting_effect()
	{	$effects = array('random', 'cubeH', 'cubeV', 'fade', 'sliceH', 'sliceV', 'slideH', 'slideV', 'scale', 'blockScale', 'kaleidoscope', 'fan', 'blindH', 'blindV');
		?>
		<select name="bd_refineslide_settings[effect]">
			<?php foreach($effects as $e): ?>
			<option value="<?php echo $e; ?>" <?php if($this->get_refineslide_option('effect') == $e) echo 'selected="selected"' ?>><?php echo $e; ?></option>
			<?php endforeach; ?>
		</select>
		<?php
	}

	// --------------------------------------------------------------------------

	function setting_navigation()
	{	$nav_type = array('arrows', 'thumbs', 'none');
		?>
		<select name="bd_refineslide_settings[navigation]">
			<?php foreach($nav_type as $n): ?>
			<option value="<?php echo $n; ?>" <?php if($this->get_refineslide_option('navigation') == $n) echo 'selected="selected"' ?>><?php echo $n; ?></option>
			<?php endforeach; ?>
		</select>
		<?php
	}

	// --------------------------------------------------------------------------


	function refineslide_settings()
	{
		?>
		<div class="wrap">
			<div id="icon-themes" class="icon32"></div>
			<h2><?php _e('RefineSlide Settings', 'bd'); ?></h2>
			<form action="options.php" method="post">
				<?php settings_fields( 'bd-refineslide-settings' ); ?>
				<?php do_settings_sections( 'bd-refineslide-settings' ); ?>
				<p class="submit"><input name="save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'bd' ); ?>" /></p>
			</form>
			<p style="margin-top:20px"><?php _e('Visit the official refineslide Website', 'bd'); ?>:<br>
				<a target="_blank" href="http://refineslide.frebsite.nl/">http://refineslide.frebsite.nl/</a></p>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------

	function get_refineslide_option($value = null)
	{
		global $options;

		$bd_refineslide_settings = get_option('bd_refineslide_settings');
		
		if( isset($bd_refineslide_settings[$value]) )
			return $bd_refineslide_settings[$value];
		else
			return null;
	}

	// --------------------------------------------------------------------------

	function refineslide_panel()
	{
		include_once BD_REFINESLIDE_DIR . '/bd-refineslide-panel.php';
	}

	// --------------------------------------------------------------------------

	function refineslide_show()
	{
		include_once BD_REFINESLIDE_DIR . '/bd-refineslide-show.php';
	}


} // end class
$bd_refineslide = new BdRefineSlide;
?>