<?php
/**
* Set your language here
*/

// uncomment the line below to make the bd_set_lang function active
// Replace the languague code by your own
// The .po and .mo files can be found in the languages/ folder

//add_filter( 'locale', 'bd_set_lang' );
function bd_set_lang( $locale )
{
	return 'fr_FR';
}


/**
* Exclude "work" , "video" & "gallery" from the post types
* Because the portfolio and galleries don't have a sidebar
* We will use this function for the custom sidebars feature
**/
function bd_post_types_sidebars()
{
	global $BD_theme;
	$tab = $BD_theme['post-types'];
	unset($tab['gallery']);
	unset($tab['video']);
	return $tab;
}

/* *
* Get the URL of the shows Page
*/
function bd_get_shows_url()
{
	$pages = get_pages(array(
	    'meta_key' => '_wp_page_template',
	    'meta_value' => 'template-shows.php'
	));
	if($pages && isset($pages[0]))
		return get_permalink($pages[0]->ID);
}

/**
* Set a new post types array for the custom header feature
* Because some post types don't have single view (shows, videos)
* So no need to display custom header metabox
*/
function bd_custom_bg_post_types()
{
	global $BD_theme;
	$tab = $BD_theme['post-types'];
	unset($tab['video']);
	$tab = array_keys($tab);
	array_push($tab, 'post', 'page', 'show');
	return $tab;
}

/**
* Custom Login Logo Option
*/
function bd_custom_login_logo(){ 

	global $option;
	$logo = BD_THEME_URL.'images/logo-login.png';
	
	if(bd_get_option('login_logo')) $logo = BD_UPLOAD_URL.bd_get_option('login_logo');   

	echo '<style  type="text/css"> h1 a { background-image:url('.$logo.')  !important; } </style>';

}  
add_action('login_head',  'bd_custom_login_logo');

/**
* Hide the admin bar when sticky menu option is on
*/
function bd_show_admin_bar(){
	
	if(bd_get_option('sticky_menu'))
		return false;
	elseif( is_user_logged_in() )
		return true;
	else
		return false;

}
add_filter( 'show_admin_bar', 'bd_show_admin_bar');


/**
* Get the "read more" link from the theme options
*/
function bd_get_more_link_text()
{
	$text = 'Read more';
	if(bd_get_option('read_more_txt')!='')
		$text = bd_get_option('read_more_txt');

	return $text;

}

/*-----------------------------------------------------------------------------------*/
/*	Page Layout
/*-----------------------------------------------------------------------------------*/

/**
* Pre-page content area
*
*/
function bd_print_headline(){
	global $post, $wp_query;
	if (have_posts() && $wp_query && isset($wp_query->queried_object->ID) ) : 
		$headline = get_post_meta( $wp_query->queried_object->ID, 'bd_page_headline', true);

		if($headline):
		?>
		<div class="headline">
			<div class="wrap"><?php echo do_shortcode( $headline ); ?></div>
		</div>
		<?php
		elseif(bd_get_option('headline')):
		?>
		<div class="headline">
			<div class="wrap"><?php echo do_shortcode( bd_get_option('headline') ); ?></div>
		</div>
		<?php

		endif;
	endif;
}
add_action('bd_page_before', 'bd_print_headline');


/**
* Post-page content area
*
*/
function bd_print_bottomline(){
	global $post, $wp_query;
	if (have_posts() && $wp_query && isset($wp_query->queried_object->ID) ) : 
		$bottomline = get_post_meta( $wp_query->queried_object->ID, 'bd_page_bottomline', true);

		if($bottomline):
		?>
		<div class="bottomline">
			<div class="wrap"><?php echo do_shortcode( $bottomline ); ?></div>
		</div>
		<?php
		elseif(bd_get_option('bottomline')):
		?>
		<div class="bottomline">
			<div class="wrap"><?php echo do_shortcode( bd_get_option('bottomline') ); ?></div>
		</div>
		<?php

		endif;
	endif;
}
add_action('bd_page_after', 'bd_print_bottomline');


/**
* Excerpt more
* Render "Read more" button
*/
function bd_excerpt_more($more)
{
	global $post;

	$class = 'more-link';
	
	if(bd_get_option('read_more_class'))
		$class = bd_get_option('read_more_class');

	$text = __('Read more', 'bd').'';

	if(bd_get_option('read_more_txt')!='')
		$text = bd_get_option('read_more_txt');

	return '...<p>
	<a href="'. get_permalink($post->ID) . '" class="'.$class.'">'.$text.'</a>
	</p>';
       
}
add_filter('excerpt_more', 'bd_excerpt_more');


/**
* Excerpt lenght hook 
* Get the number of character to diaplay on the excerpt from the theme options
*/
function bd_excerpt_length($length)
{

	if(bd_get_option('excerpt_length'))
		return bd_get_option('excerpt_length');
	else
		return 55; 

}
add_filter('excerpt_length', 'bd_excerpt_length');


/**
* Avoid page jump when clicking on more link
*/
add_filter('the_content_more_link', 'bd_remove_more_jump_link');
function bd_remove_more_jump_link($link) 
{
	$offset = strpos($link, '#more-');
	if ($offset) { $end = strpos($link, '"',$offset); }
	if ($end) { $link = substr_replace($link, '', $offset, $end-$offset); }
	return $link;
}



/**
*  Display One-Song Audio Player
*/
function bd_jplayer($post_id, $mp3 = null, $ogg = null)
{
	wp_enqueue_script('jplayer-solo', BD_THEME_URL. 'js/jplayer.min.js', 'jquery', '2.1');
	
	$rand = rand(1,999);
	$post_id = $post_id.$rand;
	$html='';
	$html .='<script type="text/javascript">    
		jQuery(document).ready(function($){
			$("#jquery_jplayer_'.$post_id.'").jPlayer({
				ready: function () {
					$(this).jPlayer("setMedia", {
						mp3: "'.$mp3.'", ';
						if($ogg)
							$html .= 'oga: "'.$ogg.'" ';

						$html .='                                 
					});
				},
			swfPath: "'.BD_THEME_URL.'js",
			cssSelectorAncestor: "#jp_interface_'.$post_id.'",
			supplied: "oga,mp3"
			});
		});
	</script>';
	$html .='<div class="solo-player">
			<div id="jquery_jplayer_'.$post_id.'" class="jp-jplayer jp-jplayer-audio"></div>
			<div class="jp-audio-container">
				<div class="jp-audio">
					<div class="jp-type-single">
						<div id="jp_interface_'.$post_id.'" class="jp-interface">
							<ul class="jp-controls">
								<li><div class="seperator-first"></div></li>
								<li><div class="seperator-second"></div></li>
								<li><a href="#" class="jp-play" tabindex="1">play</a></li>
								<li><a href="#" class="jp-pause" tabindex="1">pause</a></li>
								<li><a href="#" class="jp-mute" tabindex="1">mute</a></li>
								<li><a href="#" class="jp-unmute" tabindex="1">unmute</a></li>
							</ul>
							<div class="jp-progress-container">
								<div class="jp-progress">
									<div class="jp-seek-bar">
										<div class="jp-play-bar"></div>
									</div>
								</div>
							</div>
							<div class="jp-volume-bar-container">
								<div class="jp-volume-bar">
									<div class="jp-volume-bar-value"></div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>';
	return  $html;       
}



/**
*  Display Post Slider with the post attachments
* @param string : image format
**/
function bd_post_slider($format = 'default', $resize = 1)
{
	
	global $post;
	$post_id = $post->ID;

	$rand = rand(1,999);
	$post_id = $post_id.$rand;
	$html = '';
	
	$args = array(
		'post_type' => 'attachment',
		'numberposts' => -1,
		'post_status' => null,
		'orderby' => 'menu_order',
		'order' => 'ASC',
		'post_parent' => $post->ID
		);

	$attachments = get_posts( $args );
	
	
		if ( $attachments ) {

			$html .='<script type="text/javascript">
				jQuery(window).load(function(){
					jQuery("#slider-'.$post_id.' .slides li").first().find("img").css({"opacity": 1});
					jQuery("#slider-'.$post_id.'").css("background-image","none");
					jQuery("#slider-'.$post_id.'").flexslider({
						animation : "fade",
						slideshow : false,
						slideshowSpeed: 3500,
						smoothHeight: true
					});    
				});
			</script>';

			$html .= '<div class="flexslider post-slider" id="slider-'.$post_id.'"><ul class="slides">';

			foreach ( $attachments as $attachment ) {
				$class = "post-attachment mime-" . sanitize_title( $attachment->post_mime_type );
				$img_src = wp_get_attachment_image_src( $attachment->ID, $format);
				$alt = get_post_meta($attachment->ID , '_wp_attachment_image_alt', true);
				
				$uploads = wp_upload_dir();
				$file_path = str_replace( $uploads['baseurl'], $uploads['basedir'], $img_src );

				$size = getimagesize($file_path[0]);
				
				$max_w = 1240;
				$max_h = 630;
				$w = $size[0];
				$h = $size[1];

				$x = ($max_h*$w)/$h;
				$x = ceil($x);
				$y = 100*$x/$max_w;

				$style= null;
				
				if( $resize == 2 || $resize == 1 && $h >= $w)
				 	$style = ' style="width:'.$y.'%"';

				$html .= '<li class="' . $class . ' data-design-thumbnail">'; 
					$html .= '<img src="'.$img_src[0].'"'.$style.' alt="'.$alt.'">';
				
				if( $attachment->post_excerpt != '' )
					$html .= '<p class="flex-caption">'.$attachment->post_excerpt.'</p>';
				
				$html .= '</li>';
			}

			$html .= '</ul></div>';
		}

	return $html;
}



/*-----------------------------------------------------------------------------------*/
/*	Shows Functions
/*-----------------------------------------------------------------------------------*/

/**
*  Format date from Mysql
*
*/
if ( ! function_exists( 'bd_date_format' ) ) :
function bd_date_format($date){
	list($monthnbr, $day, $year) = explode("-", $date);
	$search  = array('01','02','03','04','05','06','07','08','09','10','11','12');
	$replace = array(__('Jan', 'bd'),__('Feb', 'bd'),__('Mar', 'bd'),__('Apr', 'bd'),__('May', 'bd'),__('Jun', 'bd'),__('Jul', 'bd'),__('Aug', 'bd'),__('Sep', 'bd'),__('Oct', 'bd'),__('Nov', 'bd'),__('Dec', 'bd'));
	$month = str_replace($search, $replace, $monthnbr);
	return $month.'. '.$day.', '. $year;
}
endif;

/**
*  Format date from Mysql for mobile (mm/dd/yy)
*
*/
if ( ! function_exists( 'bd_date_mobile_format' ) ) :
function bd_date_mobile_format($date){
	list($month, $day, $year) = explode("-", $date);
	return $month.'-'.$day.'-'. $year;
}
endif;

/**
*  Format date from Mysql for mobile (mm/dd/yy)
*
*/
if ( ! function_exists( 'bd_custom_date_format' ) ) :
function bd_custom_date_format($date){
	list($monthnbr, $day, $year) = explode("-", $date);
	$search  = array('01','02','03','04','05','06','07','08','09','10','11','12');
	$replace = array(__('Jan', 'bd'),__('Feb', 'bd'),__('Mar', 'bd'),__('Apr', 'bd'),__('May', 'bd'),__('Jun', 'bd'),__('Jul', 'bd'),__('Aug', 'bd'),__('Sep', 'bd'),__('Oct', 'bd'),__('Nov', 'bd'),__('Dec', 'bd'));
	$month = str_replace($search, $replace, $monthnbr);
	return '<div class="bd-custom-date"><span class="bd-custom-day">'.$day.'</span><span class="bd-custom-month">'.$month.'</span><span class="bd-custom-year">'.$year.'</span></div>';
}
endif;


/**
* Shows post type query
*
*/
function bd_shows_query($future = true)
{
	global $wpdb;
	$shows_query = "SELECT wposts.* 
		FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta
		WHERE wposts.ID = wpostmeta.post_id
		AND wpostmeta.meta_key = 'bd_show_date' ";
	
	if($future)
		$shows_query .= "AND STR_TO_DATE(wpostmeta.meta_value,'%m-%d-%Y') >= CURDATE()";
	elseif(!$future)
		$shows_query .= "AND STR_TO_DATE(wpostmeta.meta_value,'%m-%d-%Y') < CURDATE()";

	if($future)
		$order = 'ASC';
	elseif(!$future)
		$order = 'DESC';
	
	$shows_query .= "AND wposts.post_status = 'publish'
		AND wposts.post_type = 'show'
		ORDER BY STR_TO_DATE(wpostmeta.meta_value,'%m-%d-%Y') $order
		LIMIT 100
		";


	return $shows_query;
}


/*-----------------------------------------------------------------------------------*/
/*	Tobar message
/*-----------------------------------------------------------------------------------*/


/**
* Add CSS to display top bar message or not depending on theme options
*/
function bd_topbar_options(){

	$display = bd_get_option('topbar_display');

	$output = "\n";

	$open = '#topbar {display:block;}';

	$close = '#topbar {display:none;} #topbar-container #ribbon {top : 0}';


	if(bd_get_option('topbar_text')){
		$output .=  '<style type="text/css">';

		if( $display == 'open' ){

			$output .= $open;

		}elseif( $display == 'close' ){

			$output .= $close;

		}elseif( $display == 'cookie' ){

			if( !isset($_COOKIE["topbar"]) ){

				//setcookie("topbar", "open", 3600, '/');
				$output .= $open;
			}else{

				if( $_COOKIE["topbar"] == 'open' ){

					$output .= $open;

				}elseif( $_COOKIE["topbar"] == 'close' ){

					$output .= $close;

				}

			}

		}

		$output .= '</style>';
	}

	echo $output;

}
add_action('bd_head', 'bd_topbar_options');



/*-----------------------------------------------------------------------------------*/
/*  Theme Shortcodes & Custom functions
/*-----------------------------------------------------------------------------------*/


/* Last Posts Module
-----------------------------------------------*/
function bd_custom_last_posts($count = 4, $cat = null, $tag = null)
{
	ob_start();

	$args = array( 
		'post_type' => array('post'),
		'posts_per_page' => $count,
	);

	if( $cat )
		$args['category_name'] = $cat;

	if( $tag )
		$args['tag'] = $tag;

	
	$loop = new WP_Query($args);
	
	if($loop->have_posts()): ?>
	<div class="module">
	<?php while ( $loop->have_posts() ) : $loop->the_post(); 
		$title= get_the_title();
		$post_sample = bd_sample(get_the_excerpt(), 200).' <a href="' . get_permalink() . '">' . __('Read more', 'bd') . '</a>';
		if(preg_match('#https://twitter.com#', get_the_content())){
			$post_sample = the_content();
			$title = '';
		}

	?>
	
		<article <?php post_class(); ?>   id="post-<?php the_ID(); ?>">
			<h3 class="entry-title">
				<a class="entry-link" rel="bookmark" title="<?php printf(__('Permanent Link to %s', 'bd'), get_the_title()); ?>" href="<?php echo esc_url( get_permalink() ); ?>">
					<?php echo $title; ?>
				</a>
			</h3>
			<p>
				<?php if(has_post_thumbnail()): ?>
				<a class="preview" href="<?php the_permalink(); ?>"><img style="float:left; margin-right:15px; margin-bottom:15px" src="<?php echo bd_get_post_thumbnail_url('mini'); ?>" alt="<?php echo sanitize_title(get_the_title()); ?>"></a>
				<?php endif; ?>
				<?php echo $post_sample; ?>
			</p>
			<div class="clear"></div>
			
		</article>
		<hr style="margin:20px 0 10px">
	<?php endwhile; ?>
		<a href="<?php echo bd_blog_url(); ?>" class="more-link">
			<?php _e('Read more news', 'bd'); ?>
		</a>
	</div>
	<?php endif;
	wp_reset_query();
	wp_reset_postdata();
	$html = ob_get_contents();
	ob_end_clean();
	return $html;
}

add_shortcode ('bd_last_posts', 'bd_custom_last_posts_shortcode');
function bd_custom_last_posts_shortcode($atts)
{
	extract(shortcode_atts(array(
	      "count" => 4,
	      "category" => null,
	      "tag" => null
	), $atts));
	if(function_exists('bd_custom_last_posts'))
		return bd_custom_last_posts($count, $category, $tag);
}



function bd_custom_last_albums($count = 3, $cat = null)
{
	ob_start();

	$args = array( 
		'post_type' => array('gallery'),
		'posts_per_page' => $count,
	);

	if( $cat ){
		$args['gallery-category'] = $cat;
	}
	
	$loop = new WP_Query($args);
	if($loop->have_posts()): ?>
	<div id="home-albums-grid" class="clearfix">
		<?php while ($loop->have_posts()) : $loop->the_post(); ?>
		<?php if(has_post_thumbnail()): ?>
		<div <?php post_class(array('album-item-container')); ?> id="post-<?php the_ID(); ?>">
			<div class="album-item">
				<a class="entry-link" href="<?php the_permalink(); ?>">
					<div class="album-thumb">
						<?php the_post_thumbnail('item-cover'); ?>
						<div class="album-title">
							<h5><?php the_title(); ?></h5>
							<p><?php _e('View Gallery', 'bd'); ?></p>
						</div>
					</div>
				</a>
			</div>
		</div>
		<?php endif; ?>
		<?php endwhile; ?> 
	</div>
	<?php 
	else: // if no posts
		
		?><article id="post-0" class="post no-results not-found">
			<div class="entry-content">
				<p class="center"><?php _e('No album yet.', 'bd'); ?></p>
			</div>
		</article><?php
	
	endif;
	wp_reset_query();
	wp_reset_postdata();
	$html = ob_get_contents();
	ob_end_clean();
	return $html;
}

add_shortcode ('bd_last_albums', 'bd_homepage_last_albums_shortcode');
function bd_homepage_last_albums_shortcode($atts)
{
	extract(shortcode_atts(array(
	      "count" => 3,
	      "category" => null
	), $atts));
	if(function_exists('bd_custom_last_albums'))
		return bd_custom_last_albums($count, $category);
}

function bd_custom_last_videos($count = 3)
{
	wp_enqueue_script( 'fancybox-media');
	ob_start();

	$loop = new WP_Query("post_type=video&showposts=$count");
	if($loop->have_posts()): ?>
	<div id="home-videos-grid" class="clearfix">
		<?php while ($loop->have_posts()) : $loop->the_post(); 
		$video = get_post_meta(get_the_ID(), '_format_video_embed', true);
		$video_url = bd_get_video_url($video);
		?>
		<?php if(has_post_thumbnail()): ?>
		<div <?php post_class(array('video-item-container')); ?> id="post-<?php the_ID(); ?>">
			<div class="video-item">
				<a class="fancybox-media entry-link" href="<?php echo $video_url; ?>" title="<?php printf(__('Watch %s', 'bd'), get_the_title()); ?>">
					<div class="video-thumb">
						<span class="play-overlay"></span>
						<?php the_post_thumbnail('item-cover'); ?>
						<div class="video-title">
							<h5><?php the_title(); ?></h5>
						</div>
					</div>
				</a>
			</div>
		</div>
		<?php endif; ?>
		<?php endwhile; ?> 
	</div>
	<?php 
	else: // if no posts
		
		?><article id="post-0" class="post no-results not-found">
			<div class="entry-content">
				<p class="center"><?php _e('No video yet.', 'bd'); ?></p>
			</div>
		</article><?php
	
	endif;
	wp_reset_query();
	wp_reset_postdata();
	$html = ob_get_contents();
	ob_end_clean();
	return $html;
}

add_shortcode ('bd_last_videos', 'bd_homepage_last_videos_shortcode');
function bd_homepage_last_videos_shortcode($atts)
{
	extract(shortcode_atts(array(
	      "count" => 3
	), $atts));
	if(function_exists('bd_custom_last_videos'))
		return bd_custom_last_videos($count);
}


add_filter( 'post_gallery', 'bd_custom_gallery', 10, 2 );
function bd_custom_gallery( $output, $attr )
{
	global $post, $wp_locale;

	$is_masonry = get_post_type( $post->ID ) == 'gallery';

	if ( $is_masonry ) {
		$size = 'photo';
	} else {
		$size = 'thumbnail';
	}

	static $instance = 0;
	$instance++;

	// We're trusting author input, so let's at least make sure it looks like a valid orderby statement
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		
		if ( !$attr['orderby'] )
			unset( $attr['orderby'] );
	}

	extract(shortcode_atts(array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ID',
		'id'         => $post->ID,
		'itemtag'    => 'div',
		'icontag'    => 'div',
		'captiontag' => 'dd',
		'columns'    => 3,
		'size'       => $size,
		'include'    => '',
		'exclude'    => ''
	), $attr));

	$id = intval($id);
	if ( 'RAND' == $order )
		$orderby = 'none';

	if ( !empty($include) ) {
		$include = preg_replace( '/[^0-9,]+/', '', $include );
		$_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}

	} elseif ( !empty($exclude) ) {
		$exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
		$attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	} else {
		$attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	}

	if ( empty($attachments) )
		return '';

	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $att_id => $attachment )
		$output .= wp_get_attachment_link($att_id, $size, true) . "\n";
		return $output;
	}

	$itemtag = tag_escape($itemtag);
	$captiontag = tag_escape($captiontag);
	$columns = intval($columns);
	$itemwidth = $columns > 0 ? floor(100/$columns) : 100;
	$float = is_rtl() ? 'right' : 'left';

	$selector = "gallery";


	$open_tag = "<div id='$selector' class='clearfix'>";

	if ( $is_masonry ) {
		$open_tag = "<div id='$selector' class='masonry clearfix'>";
	}
		$open_tag .= '<ul>';

	$gallery_style = '';

	if ( ! $is_masonry  ){
		$gallery_style = "<style type='text/css'>
	            #{$selector} {
		   list-style-type : none!important;
	                margin: auto;
	                margin-bottom:1em;
	                min-height:1px;
	            }
	            #{$selector} ul li {
	            	    list-style-type : none!important;
	            	    margin:0;
	            	    padding:0;
	                float: {$float};
	                margin-top: 10px;
	                text-align: center;
	                width: {$itemwidth}%;           }
	            #{$selector} img {
	                border: 1px solid #333;
	            }
	            #{$selector} .gallery-caption {
	                margin-left: 0;
	            }
	        </style>";

	        $itemtag = 'li';
	}

	$output = apply_filters('gallery_style', "$gallery_style
	<!-- see gallery_shortcode() in wp-includes/media.php -->
	$open_tag");


	$i = 0;
	foreach ( $attachments as $id => $attachment ) {
		$caption = '';
		$class = 'fancybox';

		if ( $is_masonry )
			$class = 'zoom fancybox';

		$img = wp_get_attachment_image_src($id, $size, false, false);
		$full = wp_get_attachment_image_src($id, 'full', false, false);

		if ( $captiontag && trim($attachment->post_excerpt) )
			$caption = wptexturize($attachment->post_excerpt);

		if($img[0] && $full[0])
			$img = '<a title="'. $caption .'" class="' . $class . '" href="'. $full[0] .'"><img src="' . $img[0] . '" alt="'. wptexturize($attachment->post_title) .'"></a>';

		if ( $is_masonry )
			$output .= "<{$itemtag} class='photo-item'>";
		else
			$output .= "<{$itemtag}>";
		
		$output .= "$img";
		$output .= "</{$itemtag}>";
	}

	if ( ! $is_masonry )
		$output .= '</ul>';

	$output .= "<div class='clear'></div></div>\n";

	return $output;
}
?>
