<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Taxonomy Widget
	Plugin URI: http://themes.brutaldesign.com
	Description: A widget that displays any taxonomy
	Version: 1.0
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_taxonomy_display_init');

function bd_taxonomy_display_init(){

	register_widget('bd_taxonomy_display_Widget');
	
}

/*-----------------------------------------------------------------------------------*/
/*  Widget Class
/*-----------------------------------------------------------------------------------*/
class bd_taxonomy_display_widget extends WP_Widget {

	/*-----------------------------------------------------------------------------------*/
	/*  Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_taxonomy_display_widget(){

		// Widget settings
		$ops = array('classname' => 'widget_taxonomy', 'description' => __('Display any custom taxonomy', 'bd'));

		// Create the widget
		$this->WP_Widget('widget_taxonomy', 'Taxonomy', $ops);
		
	}

	/*-----------------------------------------------------------------------------------*/
	/*  Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget($args, $instance){
		
		extract($args);
		
		$title = apply_filters('widget_title', $instance['title']);
		$count = $instance['count'];
		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		bd_taxonomy_display($count, $instance['post-type']);
		echo $after_widget;
	
	}

	/*-----------------------------------------------------------------------------------*/
	/*  Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance){
		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];
		$instance['count'] = $new_instance['count'];
		$instance['post-type'] = $new_instance['post-type'];


		return $instance;
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form($instance){
		global $BD_theme;
		// Set up some default widget settings
		$defaults = array('title' => 'Categories', 'count' => 'off', 'post-type' => '');
		$instance = wp_parse_args((array) $instance, $defaults);
		$checked='';
		if($instance['count']=='on')
		$checked='checked="checked"';

		$custom_taxonomies = array();
		foreach($BD_theme['taxonomy'] as $k => $v){
			$custom_taxonomies[$k] = $v['singular'];
		}
		//debug($custom_taxonomies);
		?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd' ); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>">
		</p>
		<p>
			
			<input <?php echo $checked; ?> class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>">
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Show count', 'bd' ); ?>:</label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('post-type'); ?>">Taxonomy:</label>
			<select name="<?php echo $this->get_field_name('post-type'); ?>" id="<?php echo $this->get_field_id('post-type'); ?>">
				<?php foreach ($custom_taxonomies as $k => $v): ?>
					<option value="<?php echo $k; ?>" <?php if($instance['post-type'] == $k) { echo 'selected="selected"'; }; ?>><?php echo $v; ?></option>
				<?php endforeach;  ?>
			</select>
		</p>
		<?php
	}

	

}

	/*-----------------------------------------------------------------------------------*/
	/*	Taxonomy function
	/*-----------------------------------------------------------------------------------*/
	function bd_taxonomy_display($count='on', $id){
		global $BD_theme;
		
		$tslug = $BD_theme['taxonomy'][$id]['singular'];
		
		if(get_option('permalink_structure')!=''){
			$slug =  $tslug.'/';
		}else{
			$slug = '?'.$tslug.'=';
		}
		
		$taxonomy     = $id;
		$orderby      = 'slug'; 
		$show_count   = 1;      // 1 for yes, 0 for no
		$pad_counts   = 0;      // 1 for yes, 0 for no
		$hierarchical = 1;      // 1 for yes, 0 for no
		$title        = '';

		$args = array(
			'taxonomy'     => $taxonomy,
			'orderby'      => $orderby,
			'show_count'   => $show_count,
			'pad_counts'   => $pad_counts,
			'hierarchical' => $hierarchical,
			'title_li'     => $title
		); 
		$cat = get_categories( $args );
		echo "<ul class=\"square\">";
		foreach($cat as $c):
			?>
			<li><a class="hover" href="<?php echo home_url(); ?>/<?php echo $slug.$c->slug; ?>"><?php echo $c->name; ?></a> <?php if($count == 'on') echo '('.$c->count.')'; ?></li>
			<?php
		endforeach;
		echo "</ul>";
	}        
?>