<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Twitter Widget
	Plugin URI: http://themes.brutaldesign.com
	Description: A widget that displays your Twitter Feed
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_twitter_init');

function bd_twitter_init(){

	register_widget('bd_twitter_widget');
	
}

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class bd_twitter_widget extends WP_Widget {
	
	/*-----------------------------------------------------------------------------------*/
	/*	Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_twitter_widget(){

		// Widget settings
		$ops = array(
			'classname' => 'twitter-widget', 
			'description' => __('Display your latest tweets', 'bd'));

		// Create the widget
		$this->WP_Widget('twitter-widget', 'Twitter', $ops);
		
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget($args, $instance){
		
		extract($args);
		
		$title = apply_filters('widget_title', $instance['title']);
		$username = $instance['username'];
		$count = $instance['count'];

		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		echo bd_twitter($username, $count);
		echo $after_widget;
	
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance){

		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];

		$instance['username'] = $new_instance['username'];

		$instance['count'] = $new_instance['count'];
		if($instance['count']==0 || $instance['count']=='') $instance['count'] = 3;
		if($instance['username']=='') $instance['username'] = 'username';
		return $instance;
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form($instance){

			// Set up some default widget settings
			$defaults = array('title' => __('Twitter Feed', 'bd'), 'username' => 'username',  'count' =>'3');
			$instance = wp_parse_args((array) $instance, $defaults);

		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('username'); ?>"><?php _e('Your Twitter username', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('username'); ?>" name="<?php echo $this->get_field_name('username'); ?>" value="<?php echo $instance['username']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Number of tweets', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" value="<?php echo $instance['count']; ?>">
		</p>
		<?php
	}

	

}

/*-----------------------------------------------------------------------------------*/
/*	Twitter functions
/*-----------------------------------------------------------------------------------*/

function bd_twitter_error(){

	$output = '<p>'.__('Sorry, could not load tweets.', 'bd').'</p>';
	
	if ( is_user_logged_in() )
		$output = '<p>'.__('Sorry, could not load tweets. Please double check your twitter username.', 'bd').'</p>';


	return $output;

}

/* Get the Twitter XML feed */
function bd_get_twitter_xml($username){

	$trans_key = 'bd_twitter_'.$username;
	$rss_url = "http://api.twitter.com/1/statuses/user_timeline.rss?screen_name=$username";

	if ( false === ( $cached_xml = get_transient( $trans_key ) ) ){
		if( function_exists('curl_init') ){
			$c = curl_init($rss_url);
			curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($c, CURLOPT_HEADER, 0);
			curl_setopt($c, CURLOPT_TIMEOUT, 10);
			$xml = curl_exec($c);
			curl_close($c);
		} else {
			$xml = file_get_contents($rss_url);
		}
		
		if ($xml){
			set_transient( $trans_key, $xml, BD_CACHE_DURATION ); 
		}
	}else{
		$xml = $cached_xml;
	}
		
	return @simplexml_load_string($xml);	
}        

/* Display tweets as list or single tweet */
function bd_twitter($username, $count = 3, $list = true){
	
	$tweet ='';

	if( bd_get_twitter_xml($username) ){
		$xml = bd_get_twitter_xml($username);
		if($list){
			if($xml->channel->item[0]){
				for ($i=0; $i<$count; $i++){
					if($xml->channel->item[$i]){
						$lasttweet = str_replace($username.':', '', $xml->channel->item[$i]->title);
						$created = $xml->channel->item[$i]->pubDate;
						$tweet_link = $xml->channel->item[$i]->link;
						$tweet .= "<ul class=\"tweet_list\">"; 
						$tweet .= "<li>";
						$tweet .= "<span class=\"tweet_time\"><a href=\"$tweet_link\" target=\"_blank\">".__('about', 'bd')." ".bd_twitter_time_ago($created)."</a></span>";    
						$tweet .= "<span class=\"tweet_text\">".bd_twitter_to_link($lasttweet)."</span>";
						$tweet .= "</li>";
						$tweet .= "</ul>";
					}
				}
			}else{
				$tweet = bd_twitter_fallback($username, $count , $list);
			}
		}else{
			if($xml->channel->item[0]){
				$lasttweet = str_replace($username.':', '', $xml->channel->item[0]->title);
				$created = $xml->channel->item[0]->pubDate;
				$tweet_link = $xml->channel->item[0]->link;
				$tweet .= "<div class=\"bigtweet-content\"><span class=\"tweet_text\">".bd_twitter_to_link($lasttweet)."</span>";
				$tweet .= "<br><span class=\"tweet_time_big\"><a href=\"$tweet_link\" target=\"_blank\">".__('about', 'bd')." ".bd_twitter_time_ago($created)."</a> 
				<span class=\"themecolor\">|</span> <a href=\"http://twitter.com/$username/\" target=\"_blank\">@$username</a></span></div>"; 
			}else{
				$tweet = bd_twitter_fallback($username, 1, false);
			}
		}

	}else{
		//$tweet = bd_twitter_error();
		$tweet = bd_twitter_fallback($username, $count , $list);

	}
	
	return $tweet;
}


/**
* Find url strings and username strings and make them link
**/
function bd_twitter_to_link($text) {
	// Match URLs
	$text = preg_replace('`\b(([\w-]+://?|www[.])[^\s()<>]+(?:\([\w\d]+\)|([^[:punct:]\s]|/)))`', '<a href="$0" target="_blank">$0</a>', $text);

	// Match @name
	$text = preg_replace('/(@)([a-zA-Z0-9\_]+)/', '<a href="https://twitter.com/$2" target="_blank">@$2</a>', $text);

	// Match #hashtag
	$text = preg_replace('/(#)([a-zA-Z0-9\_]+)/', '<a href="https://twitter.com/search/?q=$2" target="_blank">#$2</a>', $text);
	    return $text;
}
	    
/**
* Convert the twitter date to "X ago" type
**/        
function  bd_twitter_time_ago($date){
	$h         = date("H", strtotime($date));
	$m         = date("i", strtotime($date));
	$s         = date("s", strtotime($date));
	$d         = date("d", strtotime($date));
	$m         = date("m", strtotime($date));
	$y         = date("Y", strtotime($date));
	$timestamp = mktime($h,$m,$s,$m,$d,$y);
	$stf       = 0;
	$cur_time  = time();
	$diff      = $cur_time - $timestamp;
	$phrase = array(__('second', 'bd'),__('minute', 'bd'),__('hour', 'bd'),__('day', 'bd'),__('week', 'bd'),__('month', 'bd'),__('year', 'bd'),__('decade', 'bd'));
	$length = array(1,60,3600,86400,604800,2630880,31570560,315705600);
	for($i =sizeof($length)-1; ($i >=0)&&(($no =  $diff/$length[$i])<=1); $i--); if($i < 0) $i=0; $_time = $cur_time  -($diff%$length[$i]);
	$no = floor($no); if($no <> 1) $phrase[$i] .='s'; $value=sprintf("%d %s ",$no,$phrase[$i]);
	if(($stf == 1)&&($i >= 1)&&(($cur_tm-$_time) > 0)) $value .= time_ago($_time);
	return $value.' '.__('ago', 'bd');
} 

function bd_twitter_fallback($username, $count = 3, $list = true)
{
	wp_enqueue_script('bd-twitter-widget', BD_THEME_URL . 'js/twitter.js', array('jquery'));
	$output = '';

	if($list){

		$id = rand(0,999);
		$output .= '<script type="text/javascript">
	    			jQuery(document).ready(function(){
	    				jQuery.getJSON(\'http://api.twitter.com/1/statuses/user_timeline/'.$username.'.json?count='.$count.'&callback=?\', function(tweets){
	    					jQuery("#tweet_list_'.$id.'").html(bd_format_twitter_list(tweets));
	    				});
	    			});
			</script>';

		$output .= '<ul class="tweet_list" id="tweet_list_'.$id.'"></ul>';
	}else{
		$id = rand(0,999);
		$output .= '<script type="text/javascript">
	    			jQuery(document).ready(function(){
	    				jQuery.getJSON(\'http://api.twitter.com/1/statuses/user_timeline/'.$username.'.json?count=1&callback=?\', function(tweets){
	    					jQuery("#bigtweet_'.$id.'").html(bd_format_twitter(tweets));
	    				});
	    			});
			</script>';

		$output .= '<div class="bigtweet-content" id="bigtweet_'.$id.'"></div>';
	}
	
	return $output;

}
?>